@@ -6,18 +6,17 @@ vcspull
 
 """
 
-from __future__ import absolute_import, division, print_function, \
-    with_statement, unicode_literals
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals, with_statement)
 
-import sys
 import os
+import sys
 
 
 def run():
     base = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
     sys.path.insert(0, base)
-    import vcspull
-    vcspull.cli.main()
+    import vcspull.cli
 
 if __name__ == '__main__':
     exit = run()
