@@ -1,3 +1,4 @@
+# flake8: NOQA
 import sys
 
 PY2 = sys.version_info[0] == 2
@@ -65,6 +66,8 @@ else:
     import urllib.parse as urlparse
     from urllib.request import urlretrieve
 
+    from test import support
+
     console_encoding = sys.__stdout__.encoding
 
     def console_to_str(s):
@@ -73,6 +76,8 @@ else:
             return s.decode(console_encoding)
         except UnicodeDecodeError:
             return s.decode('utf_8')
+        except AttributeError:  # for tests, #13
+            return s
 
     def reraise(tp, value, tb=None):
         if value.__traceback__ is not tb:
