@@ -6,15 +6,13 @@ vcspull.log
 
 """
 
-from __future__ import absolute_import, division, print_function, \
-    with_statement, unicode_literals
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals, with_statement)
 
 import logging
-import os
 import time
 
-from ._vendor import colorama
-from ._vendor.colorama import init, Fore, Back, Style
+from colorama import Fore, Style
 
 LEVEL_COLORS = {
     'DEBUG': Fore.BLUE,  # Blue
@@ -82,7 +80,7 @@ class LogFormatter(logging.Formatter):
 def debug_log_template(self, record):
     """ Return the prefix for the log message. Template for Formatter.
 
-    :param: record: :py:class:`logging.LogRecord` object. this is passed in
+    :param: record: :class:`logging.LogRecord` object. this is passed in
     from inside the :py:meth:`logging.Formatter.format` record.
 
     """
@@ -150,5 +148,3 @@ class RepoFilter(logging.Filter):
     def filter(self, record):
         """Only return a record if a repo_vcs object."""
         return True if 'repo_vcs' in record.__dict__ else False
-
-
