@@ -9,12 +9,9 @@ From https://github.com/saltstack/salt (Apache License):
 - :py:meth:`~._git_ssh_helper`
 - :py:meth:`~._git_run`
 - :py:meth:`GitRepo.revision`
-- :py:meth:`GitRepo.submodule`
 - :py:meth:`GitRepo.remote`
 - :py:meth:`GitRepo.remote_get`
 - :py:meth:`GitRepo.remote_set`
-- :py:meth:`GitRepo.fetch`
-- :py:meth:`GitRepo.current_branch`
 - :py:meth:`GitRepo.reset`
 
 From pip (MIT Licnese):
@@ -24,17 +21,18 @@ From pip (MIT Licnese):
 - :py:meth:`GitRepo.get_revision`
 
 """
-from __future__ import absolute_import, division, print_function, \
-    with_statement, unicode_literals
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals, with_statement)
 
-import os
 import logging
-import tempfile
+import os
 import subprocess
+import tempfile
 
-from .base import BaseRepo
-from ..util import run
 from .. import exc
+from .._compat import urlparse
+from ..util import run
+from .base import BaseRepo
 
 logger = logging.getLogger(__name__)
 
@@ -103,17 +101,31 @@ def _git_run(cmd, cwd=None, runas=None, identity=None, **kwargs):
     if retcode == 0:
         return result['stdout']
     else:
-        raise exc.PullvException(result['stderr'])
+        raise exc.VCSPullException(result['stderr'])
 
 
 class GitRepo(BaseRepo):
     schemes = ('git')
 
-    def __init__(self, arguments, *args, **kwargs):
+    def __init__(self, url, remotes=None, **kwargs):
+        """A git repository.
 
-        BaseRepo.__init__(self, arguments, *args, **kwargs)
+        :param url: URL in pip vcs format:
 
-        self['remotes']= arguments['remotes'] if 'remotes' in arguments else []
+            - ``git+https://github.com/tony/vcspull.git``
+            - ``git+ssh://git@github.com:tony/vcspull.git``
+        :type url: str
+        :param remotes: list of remotes in dict format::
+
+            [{
+            "remote_name": "myremote",
+            "url": "https://github.com/tony/vim-config.git"
+            }]
+        :type remotes: list
+        """
+        BaseRepo.__init__(self, url, **kwargs)
+
+        self['remotes'] = remotes
 
     def get_revision(self):
         current_rev = run(
@@ -130,50 +142,23 @@ class GitRepo(BaseRepo):
         work with a ssh:// scheme (e.g. Github). But we need a scheme for
         parsing. Hence we remove it again afterwards and return it as a stub.
         """
-        if not '://' in self['url']:
-            assert not 'file:' in self['url']
+        if '://' not in self['url']:
+            assert 'file:' not in self['url']
             self.url = self.url.replace('git+', 'git+ssh://')
             url, rev = super(GitRepo, self).get_url_rev()
             url = url.replace('ssh://', '')
+        elif 'github.com:' in self['url']:
+            raise exc.VCSPullException(
+                "Repo %s is malformatted, please use the convention %s for"
+                "ssh / private GitHub repositories." % (
+                    self['url'], "git+https://github.com/username/repo.git"
+                )
+            )
         else:
             url, rev = super(GitRepo, self).get_url_rev()
 
         return url, rev
 
-    def get_url(self, location):
-        url = run(
-            ['git', 'config', 'remote.origin.url'],
-            show_stdout=False, cwd=location)
-        return url.strip()
-
-    def get_revision(self, location=None):
-
-        if not location:
-            location = self['path']
-
-        current_rev = run(
-            ['git', 'rev-parse', 'HEAD'], cwd=location)['stdout']
-        return current_rev
-
-    def get_refs(self, location):
-        """Return map of named refs (branches or tags) to commit hashes."""
-        output = run(['git', 'show-ref'],
-                                 show_stdout=False, cwd=location)
-        rv = {}
-        for line in output:
-            commit, ref = line.split(' ', 1)
-            ref = ref.strip()
-            ref_name = None
-            if ref.startswith('refs/remotes/'):
-                ref_name = ref[len('refs/remotes/'):]
-            elif ref.startswith('refs/heads/'):
-                ref_name = ref[len('refs/heads/'):]
-            elif ref.startswith('refs/tags/'):
-                ref_name = ref[len('refs/tags/'):]
-            if ref_name is not None:
-                rv[ref_name] = commit.strip()
-        return rv
-
     def obtain(self, quiet=False):
         """Retrieve the repository, clone if doesn't exist.
 
@@ -185,7 +170,7 @@ class GitRepo(BaseRepo):
 
         url, rev = self.get_url_rev()
         self.info('Cloning.')
-        process = self.run(
+        self.run(
             ['git', 'clone', '--progress', url, self['path']],
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE,
@@ -193,10 +178,9 @@ class GitRepo(BaseRepo):
         )
 
         if self['remotes']:
-            self.error(self['remotes'])
             for r in self['remotes']:
-                self.error(r)
-                self.error('Adding remote %s <%s>' % (r['remote_name'], r['url']))
+                self.error('Adding remote %s <%s>' %
+                           (r['remote_name'], r['url']))
                 self.remote_set(
                     name=r['remote_name'],
                     url=r['url']
@@ -210,41 +194,16 @@ class GitRepo(BaseRepo):
                 'git', 'fetch'
             ], cwd=self['path'])
 
-            p = self.run([
+            self.run([
                 'git', 'pull'
             ], cwd=self['path'])
-
-            # if 'Already up-to-date' in proc['stdout']:
-                # self.info('Already up-to-date.')
-            # else:
-                # if proc['stderr']:
-                    # if 'You are not currently on a branch' in proc['stderr'][0]:
-                        # self.info('Not on branch, Fetched.')
-                # else:
-                    # self.info('\n'.join(proc['stdout']))
         else:
             self.obtain()
             self.update_repo()
 
-    def current_branch(self, cwd=None, user=None):
-        """Returns the current branch name, if on a branch.
-
-        CLI Example:
-
-        .. code-block:: bash
-
-            salt '*' git.current_branch /path/to/repo
-        """
-        if not cwd:
-            cwd = self['path']
-        cmd = r'git branch --list | grep "^*\ " | cut -d " " -f 2 | ' + \
-            'grep -v "(detached"'
-
-        return run(cmd, cwd=cwd, runas=user)
-
     def revision(self, cwd=None, rev='HEAD', short=False, user=None):
         """
-        Returns the long hash of a given identifier (hash, branch, tag, HEAD, etc)
+        Return long ref of a given identifier (ref, branch, tag, HEAD, etc)
 
         cwd
             The path to the Git repository
@@ -258,13 +217,7 @@ class GitRepo(BaseRepo):
         user : None
             Run git as a user other than what the minion runs as
 
-        CLI Example:
-
-        .. code-block:: bash
-
-            salt '*' git.revision /path/to/repo mybranch
         """
-        _check_git()
 
         if not cwd:
             cwd = self['path']
@@ -272,73 +225,6 @@ class GitRepo(BaseRepo):
         cmd = 'git rev-parse {0}{1}'.format('--short ' if short else '', rev)
         return run(cmd, cwd, runas=user)
 
-    def fetch(self, cwd=None, opts=None, user=None, identity=None):
-        """Perform a fetch on the given repository.
-
-        cwd
-            The path to the Git repository
-
-        opts : None
-            Any additional options to add to the command line
-
-        user : None
-            Run git as a user other than what the minion runs as
-
-        identity : None
-            A path to a private key to use over SSH
-
-        CLI Example:
-
-        .. code-block:: bash
-
-            salt '*' git.fetch /path/to/repo '--all'
-
-            salt '*' git.fetch cwd=/path/to/repo opts='--all' user=johnny
-        """
-        _check_git()
-
-        if not cwd:
-            cwd = self['path']
-
-        if not opts:
-            opts = ''
-        cmd = 'git fetch {0}'.format(opts)
-
-        return _git_run(cmd, cwd=cwd, runas=user, identity=identity)
-
-    def submodule(self, cwd, init=True, opts=None, user=None, identity=None):
-        """Initialize git submodules.
-
-        cwd
-            The path to the Git repository
-
-        init : True
-            Ensure that new submodules are initialized
-
-        opts : None
-            Any additional options to add to the command line
-
-        user : None
-            Run git as a user other than what the minion runs as
-
-        identity : None
-            A path to a private key to use over SSH
-
-        CLI Example:
-
-        .. code-block:: bash
-
-            salt '*' git.submodule /path/to/repo.git/sub/repo
-        """
-
-        if not cwd:
-            cwd = self['path']
-
-        if not opts:
-            opts = ''
-        cmd = 'git submodule update {0} {1}'.format('--init' if init else '', opts)
-        return _git_run(cmd, cwd=cwd, runas=user, identity=identity)
-
     def remotes_get(self, cwd=None, user=None):
         """Get remotes like git remote -v.
 
@@ -348,12 +234,6 @@ class GitRepo(BaseRepo):
         user : None
             Run git as a user other than what the minion runs as
 
-        CLI Example:
-
-        .. code-block:: bash
-
-            salt '*' git.remotes /path/to/repo
-
         """
 
         if not cwd:
@@ -376,13 +256,6 @@ class GitRepo(BaseRepo):
         user : None
             Run git as a user other than what the minion runs as
 
-        CLI Example:
-
-        .. code-block:: bash
-
-            salt '*' git.remote_get /path/to/repo
-            salt '*' git.remote_get /path/to/repo upstream
-
         """
 
         if not cwd:
@@ -399,9 +272,34 @@ class GitRepo(BaseRepo):
                 return res
             else:
                 return None
-        except exc.PullvException:
+        except exc.VCSPullException:
             return None
 
+    @staticmethod
+    def chomp_protocol(url):
+        """Return clean VCS url from RFC-style url
+
+        :param url: url
+        :type url: string
+        :return type: string
+        :returns: url as VCS software would accept it
+        :seealso: #14
+        """
+        if '+' in url:
+            url = url.split('+', 1)[1]
+        scheme, netloc, path, query, frag = urlparse.urlsplit(url)
+        rev = None
+        if '@' in path:
+            path, rev = path.rsplit('@', 1)
+        url = urlparse.urlunsplit((scheme, netloc, path, query, ''))
+        if url.startswith('ssh://git@github.com/'):
+            url = url.replace('ssh://', 'git+ssh://')
+        elif '://' not in url:
+            assert 'file:' not in url
+            url = url.replace('git+', 'git+ssh://')
+            url = url.replace('ssh://', '')
+        return url
+
     def remote_set(self, cwd=None, name='origin', url=None, user=None):
         """Set remote with name and URL like git remote add <remote_name> <remote_url>.
 
@@ -414,19 +312,17 @@ class GitRepo(BaseRepo):
         user : None
             Run git as a user other than what the minion runs as
 
-        CLI Example:
-
-        .. code-block:: bash
-
-            salt '*' git.remote_set /path/to/repo remote_url=git@github.com:saltstack/salt.git
-            salt '*' git.remote_set /path/to/repo origin git@github.com:saltstack/salt.git
         """
+
+        url = self.chomp_protocol(url)
+
         if not cwd:
             cwd = self['path']
         if self.remote_get(cwd, name):
             cmd = 'git remote rm {0}'.format(name)
             _git_run(cmd, cwd=cwd, runas=user)
         cmd = 'git remote add {0} {1}'.format(name, url)
+
         _git_run(cmd, cwd=cwd, runas=user)
         return self.remote_get(cwd=cwd, remote=name, user=None)
 
@@ -442,11 +338,6 @@ class GitRepo(BaseRepo):
         user : None
             Run git as a user other than what the minion runs as
 
-        CLI Example:
-
-        .. code-block:: bash
-
-            salt '*' git.reset /path/to/repo master
         """
 
         if not cwd:
