@@ -6,106 +6,23 @@ vcspull.util
 
 """
 
-from __future__ import absolute_import, division, print_function, \
-    with_statement, unicode_literals
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals, with_statement)
 
-import subprocess
-import os
-import sys
+import collections
 import errno
 import logging
-import fnmatch
+import os
+import subprocess
 
-from .exc import PullvException
+from . import exc
 from ._compat import string_types
 
+CONFIG_DIR = os.path.expanduser('~/.vcspull/')  # remove dupes of this
+
 logger = logging.getLogger(__name__)
 
 
-def expand_config(config):
-    """Return expanded configuration.
-
-    end-user configuration permit inline configuration shortcuts, expand to
-    identical format for parsing.
-
-    :param config: the repo config in :py:class:`dict` format.
-    :type config: dict
-    :rtype: dict
-
-    """
-    for directory, repos in config.items():
-        for repo, repo_data in repos.items():
-
-            '''
-            repo_name: http://myrepo.com/repo.git
-
-            to
-
-            repo_name: { repo: 'http://myrepo.com/repo.git' }
-
-            also assures the repo is a :py:class:`dict`.
-            '''
-
-            if isinstance(repo_data, string_types):
-                config[directory][repo] = {'repo': repo_data}
-
-            '''
-            ``shell_command_after``: if str, turn to list.
-            '''
-            if 'shell_command_after' in repo_data:
-                if isinstance(repo_data['shell_command_after'], string_types):
-                    repo_data['shell_command_after'] = [
-                        repo_data['shell_command_after']
-                    ]
-
-    config = dict(
-        (os.path.expandvars(directory), repo_data) for directory, repo_data in config.items()
-    )
-
-    config = dict(
-        (os.path.expanduser(directory), repo_data) for directory, repo_data in config.items()
-    )
-
-    return config
-
-
-def get_repos(config):
-    """Return a :py:obj:`list` list of repos from (expanded) config file.
-
-    :param config: the expanded repo config in :py:class:`dict` format.
-    :type config: dict
-    :rtype: list
-
-    """
-    repo_list = []
-    for directory, repos in config.items():
-        for repo, repo_data in repos.items():
-            repo_dict = {
-                'name': repo,
-                'parent_path': directory,
-                'url': repo_data['repo'],
-            }
-
-            if 'remotes' in repo_data:
-                repo_dict['remotes'] = []
-                for remote_name, url in repo_data['remotes'].items():
-                    remote_dict = {
-                        'remote_name': remote_name,
-                        'url': url
-                    }
-                    repo_dict['remotes'].append(remote_dict)
-            repo_list.append(repo_dict)
-    return repo_list
-
-
-def scan(dir):
-    """Return a list of repositories."""
-    matches = []
-    for root, dirnames, filenames in os.walk(dir):
-        for filename in fnmatch.filter(filenames, '.git'):
-            matches.append(os.path.join(root, filename))
-
-
 def run(
     cmd,
     cwd=None,
@@ -138,8 +55,8 @@ def run(
 
     try:
         proc = subprocess.Popen(cmd, **kwargs)
-    except (OSError, IOError) as exc:
-        raise PullvException('Unable to run command: {0}'.format(exc))
+    except (OSError, IOError) as e:
+        raise exc.VCSPullException('Unable to run command: %s' % e)
 
     proc.wait()
 
@@ -181,7 +98,7 @@ def which(exe=None):
             full_path = os.path.join(path, exe)
             if os.access(full_path, os.X_OK):
                 return full_path
-        raise PullvException(
+        raise exc.VCSPullException(
             '{0!r} could not be found in the following search '
             'path: {1!r}'.format(
                 exe, search_path
@@ -207,3 +124,24 @@ def mkdir_p(path):
             pass
         else:
             raise
+
+
+def update_dict(d, u):
+    """Return updated dict.
+
+    http://stackoverflow.com/a/3233356
+
+    :param d: dict
+    :type d: dict
+    :param u: updated dict.
+    :type u: dict
+    :rtype: dict
+
+    """
+    for k, v in u.items():
+        if isinstance(v, collections.Mapping):
+            r = update_dict(d.get(k, {}), v)
+            d[k] = r
+        else:
+            d[k] = u[k]
+    return d
